@@ -3,7 +3,7 @@ use std::{
     io::{Error, ErrorKind, Result},
     path::Path,
 };
-use yaml_peg::{dump, parse, repr::RcRepr};
+use yaml_peg::{dump, parser::Loader, repr::RcRepr};
 
 /// Reformat the project.
 pub fn fmt<P>(path: P, dry: bool, project: &str) -> Result<()>
@@ -11,9 +11,13 @@ where
     P: AsRef<Path>,
 {
     let path = path.as_ref().join(project);
-    let (yaml, _) = parse::<RcRepr>(&read_to_string(&path)?)
-        .map_err(|s| Error::new(ErrorKind::InvalidData, s))?;
-    let s = dump(&yaml);
+    let doc = read_to_string(&path)?;
+    let mut loader = Loader::<RcRepr>::new(doc.as_bytes()).keep_anchors(true);
+    let yaml = loader
+        .parse()
+        .map_err(|e| Error::new(ErrorKind::InvalidData, e.to_string()))?;
+    let anchor = loader.get_anchors();
+    let s = dump(&yaml, &anchor);
     if dry {
         println!("{}", s);
     } else {
