@@ -4,7 +4,7 @@ use yaml_peg::serde::Optional;
 const TEMPLATE: &str = include_str!("../assets/template.html");
 const RELOAD: &str = "\
 let ws = new WebSocket(\"ws://\" + window.location.host + \"/ws/\");
-        ws.onmessage = _ => location.reload();";
+            ws.onmessage = _ => location.reload();";
 
 /// Metadata contains HTML settings and global slide settings, they are totally YAML Maps.
 ///
@@ -12,7 +12,7 @@ let ws = new WebSocket(\"ws://\" + window.location.host + \"/ws/\");
 #[derive(serde::Deserialize)]
 #[serde(default)]
 pub struct Metadata {
-    /// Webpage icon path, "img/icon.png" by default.
+    /// Webpage icon path, defaults to "img/favicon.png".
     pub icon: String,
     /// Webpage "lang" attribute, "en" by default.
     pub lang: String,
@@ -31,9 +31,15 @@ pub struct Metadata {
     /// For local option, please see [`Slide::auto_animate`].
     #[serde(rename = "auto-animate")]
     pub auto_animate: bool,
+    /// Show chapter header on the slides.
+    #[serde(rename = "chapter-header")]
+    pub chapter_header: bool,
     /// Auto generated table of the contents (TOC), `true` by default.
     ///
-    /// To specify the outline title, just provide a string.
+    /// To specify the outline title, just provide a string,
+    /// a markdown level 1 title without `#` notation.
+    ///
+    /// Outline page has an id "outline".
     pub outline: Optional<String>,
     /// Reveal.js theme, "serif" by default.
     pub theme: String,
@@ -53,14 +59,15 @@ pub struct Metadata {
 impl Default for Metadata {
     fn default() -> Self {
         Self {
-            icon: "help/icon.png".to_string(),
+            icon: "img/favicon.png".to_string(),
             lang: "en".to_string(),
             title: String::new(),
             description: String::new(),
             author: String::new(),
             background: Background::default(),
-            outline: Optional::Bool(true),
             auto_animate: false,
+            chapter_header: false,
+            outline: Optional::Bool(true),
             theme: "serif".to_string(),
             code_theme: "zenburn".to_string(),
             style: String::new(),
@@ -82,6 +89,7 @@ impl Metadata {
             author,
             background,
             auto_animate,
+            chapter_header,
             outline,
             theme,
             code_theme,
@@ -98,6 +106,11 @@ impl Metadata {
         let ctx = Ctx {
             outline,
             auto_animate,
+            chapter_header: if chapter_header {
+                Some(Default::default())
+            } else {
+                None
+            },
             background: background.to_html(&Default::default()),
             frag: Default::default(),
         };
