@@ -30,10 +30,32 @@ pub struct Slides {
     pub slides: Vec<ChapterSlide>,
 }
 
+impl Slides {
+    /// Create single page slide.
+    pub fn single<T, D>(title: T, doc: D) -> String
+    where
+        T: ToString,
+        D: ToString,
+    {
+        let slides = vec![ChapterSlide {
+            slide: Slide {
+                title: title.to_string(),
+                content: Content {
+                    doc: doc.to_string(),
+                    ..Default::default()
+                },
+                ..Default::default()
+            },
+            ..Default::default()
+        }];
+        Metadata::default().build(Self { slides }, "/static/", true)
+    }
+}
+
 impl ToHtml for Slides {
     fn to_html(self, ctx: &Ctx) -> String {
         let Self { mut slides } = self;
-        if !ctx.outline.is_empty() {
+        if !ctx.outline.is_empty() && slides.len() > 1 {
             let doc = slides
                 .iter()
                 .enumerate()
@@ -43,7 +65,12 @@ impl ToHtml for Slides {
                     if title.is_empty() {
                         String::new()
                     } else {
-                        format!("+ [{}](#/{})\n", title, i)
+                        let id = if chapter.slide.id.is_empty() {
+                            i.to_string()
+                        } else {
+                            chapter.slide.id.clone()
+                        };
+                        format!("+ [{}](#/{})\n", title, id)
                             + &chapter
                                 .sub
                                 .iter()
@@ -51,7 +78,12 @@ impl ToHtml for Slides {
                                 .map(|(j, slide)| {
                                     let title = slide_title(slide);
                                     if !title.is_empty() {
-                                        format!("  + [{}](#/{}/{})\n", title, i, j + 1)
+                                        let id = if slide.id.is_empty() {
+                                            format!("{}/{}", i, j + 1)
+                                        } else {
+                                            slide.id.clone()
+                                        };
+                                        format!("  + [{}](#/{})\n", title, id)
                                     } else {
                                         String::new()
                                     }
@@ -60,17 +92,15 @@ impl ToHtml for Slides {
                     }
                 })
                 .collect();
-            if let Some(cover) = slides.first_mut() {
-                cover.sub.push(Slide {
-                    title: ctx.outline.clone(),
-                    content: Content {
-                        doc,
-                        ..Default::default()
-                    },
-                    background: Optional::Bool(true),
+            slides.first_mut().unwrap().sub.push(Slide {
+                title: ctx.outline.clone(),
+                id: "outline".to_string(),
+                content: Content {
+                    doc,
                     ..Default::default()
-                });
-            }
+                },
+                ..Default::default()
+            });
         }
         slides.to_html(ctx)
     }
@@ -92,8 +122,15 @@ pub struct ChapterSlide {
 impl ToHtml for ChapterSlide {
     fn to_html(self, ctx: &Ctx) -> String {
         let Self { slide, sub } = self;
-        let slide = slide.to_html(ctx) + &sub.to_html(ctx);
-        format!("<section>\n{}</section>", slide)
+        if let Some(header) = &ctx.chapter_header {
+            header.borrow_mut().clear();
+        }
+        let title = slide_title(&slide).to_string();
+        let slide = slide.to_html(ctx);
+        if let Some(header) = &ctx.chapter_header {
+            header.replace(title);
+        }
+        format!("<section>\n{}</section>", slide + &sub.to_html(ctx))
     }
 }
 
@@ -181,7 +218,14 @@ impl ToHtml for Slide {
             + &md2html(&title_only.wrap("# ", ""))
             + &content.to_html(ctx)
             + &md2html(&note).wrap("<aside class=\"notes\">", "</aside>\n");
+        let header = if let Some(header) = &ctx.chapter_header {
+            header
+                .borrow()
+                .wrap("<div class=\"chapter-header\">", "</div>")
+        } else {
+            String::new()
+        };
         ctx.frag.set(0);
-        format!("<section{}>\n{}</section>", data, content)
+        format!("<section{}>\n{}{}</section>", data, content, header)
     }
 }
